#
# spec file for package gpodder3
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gpodder3
Version:        3.9.6
Release:        lp150.1.9
Summary:        A free podcast aggregator for Linux
License:        GPL-3.0+
Group:          Productivity/Multimedia/Sound/Players
URL:            http://gpodder.org
Source:         https://github.com/gpodder/gpodder/archive/%{version}.tar.gz
Source99:       gpodder3-rpmlintrc
BuildRequires:  ImageMagick
# not actually needed, but to make the build fail if the runtime
# dependencies are not available:
BuildRequires:  MPlayer
BuildRequires:  dbus-1-python
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  help2man
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  lame
BuildRequires:  libgpod-python
BuildRequires:  python-devel
BuildRequires:  python-gtk
BuildRequires:  python-mygpoclient >= 1.4
BuildRequires:  python-podcastparser
BuildRequires:  python-pymad
BuildRequires:  update-desktop-files
BuildRequires:  vorbis-tools
Requires:       MPlayer
Requires:       dbus-1-python
Requires:       lame
Requires:       libgpod-python
Requires:       python-gtk
Requires:       python-mygpoclient >= 1.4
Requires:       python-podcastparser
Requires:       python-pymad
Requires:       vorbis-tools
Conflicts:      gpodder < 3.0.0
BuildArch:      noarch
%if 0%{?suse_version} < 1330
BuildRequires:  python-eyeD3
%endif
%if 0%{?suse_version} < 1330
Requires:       python-eyeD3
%endif

%description
gPodder manages Podcasts for you and automatically downloads selected episodes
from as many channels as you like. Synchronization support is available for
iPods and filesystem-based MP3 players, but Podcasts can (of course) also be
played with any desktop player application.

%prep
%setup -q -n gpodder-%{version}

%build

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags} PREFIX=%{_prefix}

# remove invalid locale dir
rm -rf %{buildroot}%{_datadir}/locale/kk

# script-without-shebang
chmod -x %{buildroot}%{_datadir}/gpodder/ui/gtk/*.ui

# remove shebangs from .py files that are in sitelib:
find %{buildroot}{%{python_sitelib} -name '*.py' \
| while read f; do
    case $(head -1 "$f") in
        \#!*) %__sed -i '1d' "$f" ;;
    esac
done

# recompile all .py files because their timestamp doesn't match
pushd %{buildroot}%{python_sitelib}/gpodder
%py_compile -O .
popd

rm -rf %{buildroot}%{_datadir}/icons/*/{26,40}x*

%fdupes %{buildroot}

%suse_update_desktop_file -r gpodder AudioVideo Player

%find_lang gpodder

%files -f gpodder.lang
%doc COPYING README
%{_bindir}/gpo
%{_bindir}/gpodder
%{_bindir}/gpodder-migrate2tres
%{python_sitelib}/gpodder
%{_datadir}/gpodder
%exclude %{_datadir}/gpodder/extensions/ubuntu_unity.*
%{_datadir}/applications/gpodder.desktop
%{_datadir}/applications/gpodder-url-handler.desktop
%{_datadir}/dbus-1/services/org.gpodder.service
%{_datadir}/icons/*/*/apps/gpodder.*
%{_mandir}/man1/gpo.1%{ext_man}
%{_mandir}/man1/gpodder.1%{ext_man}
%{_mandir}/man1/gpodder-migrate2tres.1%{ext_man}
%{python_sitelib}/gpodder-%{version}-py%{py_ver}.egg-info

%changelog
* Mon Jan  8 2018 fridrich.strba@bluewin.ch
- Update to 3.9.6
  * Current latest release from the Python 2, Gtk+2 and PyGTK
    branch.
* Tue Nov 14 2017 zaitor@opensuse.org
- Add conditional for python-eyeD3 BuildRequires and Requires, no
  longer available for Tumbleweed and Leap 15.
* Mon Jan  9 2017 fridrich.strba@bluewin.ch
- update to 3.9.3
  * Soundcloud: Increase track limit (by mprangenberg)
  * Fix HTTP conditional GET (Fixes #193, #182)
  * Podcastparser 0.6.1: Work around a XML parsing bug when PyXML
    is installed (#185)
* Mon Dec  5 2016 fstrba@suse.com
- update to 3.9.2
  * Fix tagging download extension (#148, patch by Eric Le Lay)
  * Improve YouTube cover art resolution (patch by Hiltronix)
  * win32-launcher: Fix crash when Python is missing
  * Sync UI: Update podcast list after sync (#136)
  * Port from feedparser to podcastparser
  * Set UI upper limit for episodes per podcast based on current value
  * Cache cover art thumbnails in SQLite database
  * Load/update the episode list model in the background
* Mon Nov  7 2016 fstrba@suse.com
- update to 3.9.1
  * win32-launcher: Fix compatibility issues with Python 2.7.11
  * Gtk UI: Remove WebKit1 support (Debian bug 790218)
  * Add 'set_artist_to_album' config option to 'tagging' extension
    (by Brian J. Cohen)
  * Resolve all symlinks in path (bug 2064)
  * Handle "mktime argument out of range" (by Markus Wamser,
    bug 2023)
  * Include OS name and version in user agent
  * Don't fail if update server is down (bug 2067)
  * Use html5lib/HTMLParser to find hyperlinks in show notes (by
    Mathias Rav)
  * desktopfile: Filter non-player apps (improves app selector
    choices on Linux)
- changes from 3.9.0:
  * Added Korean translation (by Byeongkeon Kim)
  * Device sync: Only fail if we can determine free disk space
    (bug 2052)
  * Enqueue episodes after download (Closes #133)
  * Ubuntu AppIndicator extension: 'visible' config option
  * gpodder.download: Ignore non-ASCII content-disposition header
    (bug 2059)
  * Win32-launcher: Remove download feature (works around Norton
    warning)
  * Remove WebUI, QML UI and MeeGo 1.2 Harmattan support
  * Remove broken Flattr integration (use gpodder.net's Flattr
    support)
  * Redesign about dialog
  * Preferences: Move video services to separate tab
  * Vimeo: Fix Vimeo integration
- changes from 3.8.5:
  * Vimeo
    + Fix vimeo feed discovery (bug 2009)
    + Allow both http and https URLs (bug 2019)
  * YouTube
    + youtube: Improve channel migration code
    + youtube: Fix cover art downloading (bug 2014)
    + Make the YouTube key button link to the gPodder Wiki
    + Add pattern to YouTube feed URL list (patch by Danilo Shiga)
  * CLI: Cleanup old downloads on CLI startup (bug 2012)
  * Gtk UI: Fix model column data types (bug 2008)
  * Device sync: Handle sync failure when no space left (patch by
    Aaron Wright)
  * model: Limit filenames to 120 characters for eCryptFS
    (bug 1898)
  * rename_download: Add add_sortdate and add_podcast_title option
  * Remove the unused 'pipe' IPC module
  * Fix coverage usage
  * Use Travis CI for running basic sanity tests
  * Various small code improvements and fixes
- do not ship ubuntu_unity.py plugin on SUSE
* Thu Sep 10 2015 i@margueirte.su
- update to 3.8.4
  * Show covers directly after adding feeds (bug 1987)
  * Update Sonos Extension
  * Make sure cover_url is always set (bug 1978)
  * gpodder.util: Fix timestamp issues (bug 1983)
  * gpodder.download: Strip whitespace in url (bug 1991)
  * tools/localdepends.py: Fix feedparser downloading
  * Podcast details dialog: Avoid re-showing on close
  * Updated German translation
  * Support for The Escapist
  * gpodder.directory: Remove broken YouTube search
  * YouTube: Support V3 API via user-supplied key (bug 1999)
  * YouTube: Auto-resolve URLs also in CLI and QML
  * QML UI: Add YouTube API key text entry + migrate button
  * CLI: Add "youtubefix" subcommand to rewrite URLs
  * YouTube: Match _ in channel URLs
* Sun Nov 16 2014 pascal.bleser@opensuse.org
- update to 3.8.3:
  * fixes a typo in the QML files that caused gPodder to fail to start up
  * enable "Check for updates" by default, even on non-Windows platforms
  * extension: Open website in episode list (bug 1958)
- changes from 3.8.2:
  * URL schemes (freedesktop.org and Windows)
  - Install scheme handler for gpodder://, feed://, podcast:// and pcast://
  * Gtk UI
  - New podcast directory UI
  - Keep reference to last "add podcast" dialog (bug 1021)
  - Vimeo: Support for selecting the file format (bug 1954)
  - gpodder.query: Also search in episode descriptions
  * Plugins and Extensions
  - Add support for The Escapist podcast
  - Update enqueue_in_mediaplayer.py
- changes from 3.8.1:
  * gpodder.util: Don't force password to be lowercase (bug 1942)
  * YouTube: Add support for channels, rewrite URL matching
* Thu Aug 21 2014 darin@darins.net
- update to 3.8.0
* Thu Jul  3 2014 darin@darins.net
- update to 3.7.0
* Sat Mar 30 2013 pascal.bleser@opensuse.org
- update to 3.5.0
* Tue Sep 25 2012 pascal.bleser@opensuse.org
- update to 3.3.0:
  * fixes YouTube downloading
  * adds several new extensions for better integration into Desktop
    Environments
  * decode enclosure filename properly (bug 1663)
  * remove moving files to the "Unknown" folder (bug 1612)
  * first changes for the flattr integration to better work when offline
  * sortable dates for file names on sync device
  * new extension: Gtk status icon (bug 1495)
  * respect GPODDER_DOWNLOAD_DIR in the environment (bug 466)
  * fix syncing with utf8-incompatible file names
  * new extension: TED Talks Subtitles (Pull Request #9)
  * extension: Minimize on start (bug 1633)
* Thu Jul 26 2012 pascal.bleser@opensuse.org
- update to 3.2.0:
  * translation updates
  * Flattr: Flattr-on-play integration
  * DB schema: Cleaner upgrades, fix column order
  * CLI: Show more of the title when updating feeds
  * Gtk UI: embedded shownotes display
  * QML UI: Show cover art in "All episodes" (bug 1602)
  * Add "on_channel_context_menu" callback
  * Added device sync using 'Downloads' tab to show progress
  * QML UI: Set title bar text for multi-select sheet
  * QML UI: Scroll episode list when opening last item
* Mon Apr 30 2012 pascal.bleser@opensuse.org
- update to 3.1.1:
  * JSON Config: Convert float to int (bug 1590)
  * CLI: Fix error handling bug with strerror
  * Fix 'gPodderDownloadHTTPError' object has no attribute 'errcode'
  * Gtk UI: Reintroduce "Open Download Folder" menu item
* Tue Mar 27 2012 pascal.bleser@opensuse.org
- update to 3.1.0
* Sun Feb 26 2012 pascal.bleser@opensuse.org
- update to 3.0.4: various improvements to the QML UI (for MeeGo 1.2 Harmattan
  on the Nokia N9) and the text mode interface (CLI) with new features such as:
  * gpodder.net searching from the command line
  * a play queue for the QML UI
  * episode list filtering
* Tue Jan 10 2012 pascal.bleser@opensuse.org
- update to 3.0.3:
  * adds support for subscribing to Vimeo feeds
  * various bugfixes and improvements to the common prefix elimination code for
    episode titles
* Wed Dec 14 2011 pascal.bleser@opensuse.org
- update to 3.0.2:
  * updates translations
  * fixes a bug with the ordering of YouTube episodes
  * some refinements to the QML UI for mobile devices, like the N9 running
    Harmattan
* Fri Nov 18 2011 pascal.bleser@opensuse.org
- update to 3.0.1:
  * don't hide failed attribute access in proxy
  * Gtk UI: Cosmetic fix for progress dialog labels
  * detect existing URLs on feed redirection (bug 1457)
  * Media RSS: Get filesize and duration (bug 1446)
  * Woodchuck: Make soft errors quieter (bug 1476)
  * Woodchuck: Fix spelling mistakes (bug 1473)
  * fix UnicodeDecodeError on startup (bug 1485)
* Tue Nov  8 2011 pascal.bleser@opensuse.org
- repackaged as "gpodder3" as it requires a migration of the database and ships
  quite a few major changes as compared to gpodder 2.x; gpodder 2.x is
  available as "gpodder" for now
* Mon Nov  7 2011 pascal.bleser@opensuse.org
- update to 3.0.0:
  * a brand new QML UI in addition to the existing GTK UI
  * support for Episode Query Language to filter down episode lists
  * a new on-disk single-folder data structure, allowing easy backups of the
    podcast database and downloads
- note: gpodder-backup has been removed upstream
* Sat Aug 20 2011 pascal.bleser@opensuse.org
- update to 2.18:
  * fixes problems with downloads from YouTube
* Fri Jul 22 2011 pascal.bleser@opensuse.org
- update to 2.16:
  * use $EXTERNAL_STORAGE on Android (bug 1290)
  * GTK UI: Show duration and position in shownotes (bug 1364)
  * support %%p (position) in player command (bug 1140)
  * mygpo: convert remote timestamps to local time (bug 1036)
  * fix issues with zero playback position (Maemo bug 12262)
  * sync: Fix TypeError in device cleanup (bug 611)
  * mygpo: Send timestamp as UTC to gpodder.net (bug 1036)
  * fallback to "gio" for free disk space (bug 1361), this fixes problems with
    iPods mounted via GVFS
  * avoid errors with incomplete icon themes (LP bug 782303)
  * load podcast list before update on startup (bug 1337)
* Tue May  3 2011 pascal.bleser@opensuse.org
- update to 2.15:
  * fixes problems when saving episodes to folders
  * also removes GStreamer-based track length detection, as it produced crashes
    for some users
  * description parsing support has also been improved
  * for upgrades from older installations, the database schema is repaired to
    allow multiple GUIDs in different podcasts
  * updated translations: French, Galician, Norwegian Bokmål, and Spanish
* Wed Apr 27 2011 pascal.bleser@opensuse.org
- remove dependency on gnome-btdownloader, is obsolete
* Tue Apr  5 2011 pascal.bleser@opensuse.org
- update to 2.14:
  * updated French translation
  * fixes to the tray icon behavior
  * various fixes to improve the parsing of podcast feeds
* Thu Feb 24 2011 pascal.bleser@opensuse.org
- update to 2.13:
  * bugfix release of the stable 2.x series
  * a YouTube-related directory bug was fixed
  * the UI parts of the Maemo 5 variant were improved
  * this is a recommended update for all gPodder users
* Wed Jan 12 2011 pascal.bleser@opensuse.org
- update to 2.12 "The Odyssey of Flight 33":
  * fixes a problem with upgrades from older versions where the podcast list
    would appear empty when the new version is started: the fix is both for new
    upgrades and for databases on which the upgrade failed previously (#1198)
  * fixes French translation
* Mon Dec 20 2010 pascal.bleser@opensuse.org
- update to 2.11 "Dance me a Dance":
  * fixes the broken YouTube downloads
  * fix only_sync_not_played for per-podcast sync (bug 1213): the
    only_sync_not_played configuration option was not followed when the
    per-podcast context menu item "Sync to device" was used, as all episodes of
    that podcast were forced to be copied to the device; this is now fixed, and
    only unplayed episodes will be copied in this case
  * proper single-time download notifications (bug 1161): only show a
    notification for finished or failed downloads once, both on the Desktop
    version and on Maemo 5 by adding a special function to DownloadTask to keep
    track whether or not the notification has already been shown previously
  * YouTube: better error message for protected videos: YouTube protects pages
    that contain violence, etc.. by requiring users to login to prove they are
    over 18; we can't determine the fmt_url_map in that case, so this patch
    adds a better error message to the failed download
  * ignore invalid timestamp from iPod (bug 418)
  * add support for file:// URLs for feeds (bug 1229)
  * use first Content-length header (bug 1226):  use first matching
    Content-length header when multiple found (occured with some cache/proxy
    servers)
  * fix a bug with type-less content in feeds
  * nicer download filenames for Soundcloud streams
* Sun Nov 28 2010 pascal.bleser@opensuse.org
- update to 2.10 "There Lies A Widget, Stir!":
  * shows download progress (downloaded size and file size) in the download
    list
  * new episode list icon style for all UI variants
  * support for touchscreen-based tablet PCs in the Desktop UI variant
  * various bugfixes and translation updates
* Sun Oct 10 2010 pascal@links2linux.de
- update to 2.9:
  * various small fixes to bugs and UI problems that have surfaced since the
    last release
  * now supports sorting of the episode list by name, file size, and release
    date
  * pausing of subscriptions is also supported per-podcast, allowing the feed
    update process to be more efficient for feeds that are on hiatus
* Sun Aug 29 2010 pascal@links2linux.de
- update to 2.8:
  * YouTube video downloads have been fixex: downloading HD and SD videos works
    correctly now
  * a new (experimental) XSPF parser has been added
  * many bugs and UI annoyances have been fixed
  * the translations have been updated, and a new Greek translation has been
    added
* Thu Jul  8 2010 pascal@links2linux.de
- update to 2.7:
  * adds better integration with Panucci and gpodder.net, including merging of
    retrieved episode actions from gpodder.net into the local database
  * bugfixes and up-to-date translations are included
* Sun May 23 2010 pascal@links2linux.de
- update to 2.6:
  * optimized Maemo 5 UI
  * improvements to the episode list context menu for Maemo 4 and the Desktop
    version
  * the gpodder.net integration has also been improved
* Tue Apr 20 2010 pascal@links2linux.de
- update to 2.5:
  * YouTube video downloads have been fixed
  * most translations were updated
  * some strings have been changed to make the UI more usable
* Tue Mar 30 2010 pascal@links2linux.de
- update to 2.4:
  * bugfixes
  * usability improvements
  * some parts of the episode list handing have been optimized
  * a new preferences dialog is available
* Sun Feb 28 2010 pascal@links2linux.de
- update to 2.3:
  * updated translations
  * some UI fixes
  * fixes for issues that have been reported by users since gPodder
    2.2 was released
  * the "All episodes" view is enabled by default in this version
* Mon Feb  8 2010 pascal.bleser@opensuse.org
- update to 2.2:
  * support has been added for an experimental "all episode" view and photo
    feeds (e.g. Flickr)
  * integration of my.gpodder.org (via the mygpoclient Library) has been
    included
  * a dialog for mass-unsubscribing of podcasts (instead of doing it
    one-by-one) has been added
* Sun Dec 13 2009 pascal.bleser@opensuse.org
- update to 2.1:
  * many bugs from the 2.0 release were fixed
  * support was added for search-as-you-type in the podcast and episode list
  * support was added for Soundcloud feeds
  * this release is the first to support Maemo 5 right from the release day
* Fri Sep 25 2009 pascal.bleser@opensuse.org
- update to 2.0:
  * support for episode list filtering was added
  * the UI was refreshed for Maemo 4
  * the new command-line utility "gpo" replaces the old CLI interface
  * lots of bugfixes and performance improvements were made
* Fri Jul 31 2009 pascal.bleser@opensuse.org
- update to 0.17.0:
  * fixes several bugs found in 0.16.1
  * adds an improved feed update algorithm that is able to skip updates if new
    episodes are highly unlikely
  * support for Media RSS-based podcasts has been added
* Sat Jun  6 2009 pascal.bleser@opensuse.org
- update to 0.16.1:
  * a redirection bug with YouTube has been fixed
  * timeout errors should not occur anymore for some specific feeds
  * better error reporting has been added to the GUI for low disk space
    situations and permission problems
* Tue Jun  2 2009 pascal.bleser@opensuse.org
- update to 0.16.0:
  * a new download manager with download pausing and resuming has been
    implemented
  * subscriptions can now be added by pasting URLs from the clipboard via a
    button
* Sun Apr 12 2009 pascal.bleser@opensuse.org
- update to 0.15.2:
  * fixes bugs found in version 0.15.1 and updates translation files
* Fri Mar 13 2009 pascal.bleser@opensuse.org
- update to 0.15.1:
  * fixes a compatibility bug with Python 2.6
  * two fixes that did not make it into the 0.15.0 release
* Tue Mar 10 2009 guru@unixtech.be
- update to 0.15.0:
  * adds resuming downloads between sessions
  * remembers the episodes that are downloading on exit
  * the file and folder naming has been improved, so that files and folders
    are now human-readable and easy to look at with a file manager
  * a new tool, gpodder-backup, makes it possible to back up and restore
    settings and downloads
* Tue Feb  3 2009 guru@unixtech.be
- update to 0.14.1:
  * the Spanish, Russian, Finnish, Swedish, and French translations have been
    updated
  * some bugs in the user interface have also been fixed
* Fri Dec 12 2008 guru@unixtech.be
- update to 0.14.0:
  * YouTube user channels can now be used as video podcasts that download mp4
    files
  * the user interface has been improved and gPodder can now upload and
    download podcast lists to my.gpodder.org
* Thu Oct 30 2008 guru@unixtech.be
- update to 0.13.1:
  * fixes bugs discovered since the 0.13.0 release
  * updates four translations
* Thu Oct  9 2008 guru@unixtech.be
- update to 0.13.0:
  * adds support for Media Transfer Protocol-based MP3 players (sync support)
  * implements usability interface changes
  * some bugs found since the previous version have been fixed
* Wed Sep 10 2008 guru@unixtech.be
- update to 0.12.3:
  * fix large negative values for download progress (bug 160)
  * detect and report HTTP errors when downloading (bug 106)
  * do not try to load invalid/empty RSS image tag (bug 169)
  * make gdfs-init work again (load_channels argument error)
  * improve slash and duplicate episode name handling in gdfs (bug 170)
  * fail if gpod is not available in iPod sync (bug 179)
* Sat Aug  9 2008 guru@unixtech.be
- new upstream version:
  * Swedish translation update
  * fixes problems with the cover downloader
  * corrects dialog behaviour of dialog windows
  * corrects the podcast list sorting
  * some minor problems with legacy encodings and episode file sizes have also
    been fixed
* Thu Jul 24 2008 guru@unixtech.be
- new upstream version:
  * fixes some problems with device synchronization and the command line
    interface that have been discovered in the 0.12.0 release
  * updated French translation
* Tue Jul 15 2008 guru@unixtech.be
- new upstream version:
  * automatic cover downloads
  * better file and folder naming
  * support for Rockbox Cover Art
  * SQLite database backend
* Mon Jun  2 2008 guru@unixtech.be
- new upstream version:
  * minor feature upgrades
  * a revised main menu
  * speedier updates when refreshing feeds
  * a few translations have been updated
* Sat Apr 26 2008 guru@unixtech.be
- new upstream version
* Fri Mar 28 2008 guru@unixtech.be
- new upstream version
* Mon Feb 25 2008 guru@unixtech.be
- new upstream version
* Tue Jan 22 2008 guru@unixtech.be
- new upstream version
* Fri Dec 28 2007 guru@unixtech.be
- new package
